@@ -17,6 +17,7 @@ const (
 	MachineFlyPlatformVersion2                 = "v2"
 	MachineProcessGroupApp                     = "app"
 	MachineProcessGroupFlyAppReleaseCommand    = "fly_app_release_command"
+	MachineProcessGroupFlyAppConsole           = "fly_app_console"
 	MachineStateDestroyed                      = "destroyed"
 	MachineStateDestroying                     = "destroying"
 	MachineStateStarted                        = "started"
@@ -81,6 +82,10 @@ func (m *Machine) IsFlyAppsReleaseCommand() bool {
 	return m.IsFlyAppsPlatform() && m.IsReleaseCommandMachine()
 }
 
+func (m *Machine) IsFlyAppsConsole() bool {
+	return m.IsFlyAppsPlatform() && m.HasProcessGroup(MachineProcessGroupFlyAppConsole)
+}
+
 func (m *Machine) IsActive() bool {
 	return m.State != MachineStateDestroyed && m.State != MachineStateDestroying
 }
@@ -432,13 +437,15 @@ type HTTPResponseOptions struct {
 }
 
 type MachineService struct {
-	Protocol     string                     `json:"protocol,omitempty" toml:"protocol,omitempty"`
-	InternalPort int                        `json:"internal_port,omitempty" toml:"internal_port,omitempty"`
-	Autostop     *bool                      `json:"autostop,omitempty"`
-	Autostart    *bool                      `json:"autostart,omitempty"`
-	Ports        []MachinePort              `json:"ports,omitempty" toml:"ports,omitempty"`
-	Checks       []MachineCheck             `json:"checks,omitempty" toml:"checks,omitempty"`
-	Concurrency  *MachineServiceConcurrency `json:"concurrency,omitempty" toml:"concurrency"`
+	Protocol                 string                     `json:"protocol,omitempty" toml:"protocol,omitempty"`
+	InternalPort             int                        `json:"internal_port,omitempty" toml:"internal_port,omitempty"`
+	Autostop                 *bool                      `json:"autostop,omitempty"`
+	Autostart                *bool                      `json:"autostart,omitempty"`
+	Ports                    []MachinePort              `json:"ports,omitempty" toml:"ports,omitempty"`
+	Checks                   []MachineCheck             `json:"checks,omitempty" toml:"checks,omitempty"`
+	Concurrency              *MachineServiceConcurrency `json:"concurrency,omitempty" toml:"concurrency"`
+	ForceInstanceKey         *string                    `json:"force_instance_key" toml:"force_instance_key"`
+	ForceInstanceDescription *string                    `json:"force_instance_description,omitempty" toml:"force_instance_description"`
 }
 
 type MachineServiceConcurrency struct {
