@@ -19,8 +19,8 @@ func TestToMachineConfig(t *testing.T) {
 				Protocol:     "tcp",
 				InternalPort: 8080,
 				Ports: []api.MachinePort{
-					{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHttps: true},
-					{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHttps: false},
+					{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHTTPS: true},
+					{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHTTPS: false},
 				},
 			},
 		},
@@ -38,6 +38,10 @@ func TestToMachineConfig(t *testing.T) {
 				HTTPPath: api.Pointer("/status"),
 			},
 		},
+		StopConfig: &api.StopConfig{
+			Timeout: api.MustParseDuration("10s"),
+			Signal:  api.Pointer("SIGTERM"),
+		},
 	}
 
 	got, err := cfg.ToMachineConfig("", nil)
@@ -79,8 +83,8 @@ func TestToMachineConfig_nullifyManagedFields(t *testing.T) {
 				Protocol:     "tcp",
 				InternalPort: 8080,
 				Ports: []api.MachinePort{
-					{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHttps: true},
-					{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHttps: false},
+					{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHTTPS: true},
+					{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHTTPS: false},
 				},
 			},
 		},
@@ -120,6 +124,10 @@ func TestToReleaseMachineConfig(t *testing.T) {
 		AutoDestroy: true,
 		Restart:     api.MachineRestart{Policy: api.MachineRestartPolicyNo},
 		DNS:         &api.DNSConfig{SkipRegistration: true},
+		StopConfig: &api.StopConfig{
+			Timeout: api.MustParseDuration("10s"),
+			Signal:  api.Pointer("SIGTERM"),
+		},
 	}
 
 	got, err := cfg.ToReleaseMachineConfig()
@@ -207,8 +215,8 @@ func TestToMachineConfig_defaultV2flytoml(t *testing.T) {
 				Protocol:     "tcp",
 				InternalPort: 8080,
 				Ports: []api.MachinePort{
-					{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHttps: true},
-					{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHttps: false},
+					{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHTTPS: true},
+					{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHTTPS: false},
 				},
 			},
 		},
@@ -267,8 +275,8 @@ func TestToMachineConfig_services(t *testing.T) {
 			Autostart:    api.Pointer(true),
 			Autostop:     api.Pointer(true),
 			Ports: []api.MachinePort{
-				{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHttps: true},
-				{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHttps: false},
+				{Port: api.Pointer(80), Handlers: []string{"http"}, ForceHTTPS: true},
+				{Port: api.Pointer(443), Handlers: []string{"http", "tls"}, ForceHTTPS: false},
 			},
 		},
 		{
