@@ -44,12 +44,15 @@ type ServiceHTTPCheck struct {
 }
 
 type HTTPService struct {
-	InternalPort      int                            `json:"internal_port,omitempty" toml:"internal_port" validate:"required,numeric"`
-	ForceHTTPS        bool                           `toml:"force_https" json:"force_https,omitempty"`
+	InternalPort      int                            `json:"internal_port,omitempty" toml:"internal_port,omitempty" validate:"required,numeric"`
+	ForceHTTPS        bool                           `toml:"force_https,omitempty" json:"force_https,omitempty"`
 	AutoStopMachines  *bool                          `json:"auto_stop_machines,omitempty" toml:"auto_stop_machines,omitempty"`
 	AutoStartMachines *bool                          `json:"auto_start_machines,omitempty" toml:"auto_start_machines,omitempty"`
-	Concurrency       *api.MachineServiceConcurrency `toml:"concurrency,omitempty" json:"concurrency,omitempty"`
 	Processes         []string                       `json:"processes,omitempty" toml:"processes,omitempty"`
+	Concurrency       *api.MachineServiceConcurrency `toml:"concurrency,omitempty" json:"concurrency,omitempty"`
+	TLSOptions        *api.TLSOptions                `json:"tls_options,omitempty" toml:"tls_options,omitempty"`
+	HTTPOptions       *api.HTTPOptions               `json:"http_options,omitempty" toml:"http_options,omitempty"`
+	ProxyProtoOptions *api.ProxyProtoOptions         `json:"proxy_proto_options,omitempty" toml:"proxy_proto_options,omitempty"`
 }
 
 func (s *HTTPService) ToService() *Service {
@@ -59,12 +62,17 @@ func (s *HTTPService) ToService() *Service {
 		Concurrency:  s.Concurrency,
 		Processes:    s.Processes,
 		Ports: []api.MachinePort{{
-			Port:       api.IntPointer(80),
-			Handlers:   []string{"http"},
-			ForceHttps: s.ForceHTTPS,
+			Port:              api.IntPointer(80),
+			Handlers:          []string{"http"},
+			ForceHTTPS:        s.ForceHTTPS,
+			HTTPOptions:       s.HTTPOptions,
+			ProxyProtoOptions: s.ProxyProtoOptions,
 		}, {
-			Port:     api.IntPointer(443),
-			Handlers: []string{"http", "tls"},
+			Port:              api.IntPointer(443),
+			Handlers:          []string{"http", "tls"},
+			HTTPOptions:       s.HTTPOptions,
+			TLSOptions:        s.TLSOptions,
+			ProxyProtoOptions: s.ProxyProtoOptions,
 		}},
 		AutoStopMachines:  s.AutoStopMachines,
 		AutoStartMachines: s.AutoStartMachines,
