@@ -25,9 +25,9 @@ func TestSettersWithService(t *testing.T) {
 			SoftLimit: 12,
 		},
 		HTTPChecks: []*ServiceHTTPCheck{{
-			Interval:          mustParseDuration("10s"),
-			Timeout:           mustParseDuration("2s"),
-			GracePeriod:       mustParseDuration("5s"),
+			Interval:          api.MustParseDuration("10s"),
+			Timeout:           api.MustParseDuration("2s"),
+			GracePeriod:       api.MustParseDuration("5s"),
 			HTTPMethod:        api.Pointer("GET"),
 			HTTPPath:          api.Pointer("/status"),
 			HTTPProtocol:      api.Pointer("http"),
@@ -58,13 +58,46 @@ func TestSettersWithService(t *testing.T) {
 	})
 }
 
+func TestSettersWithHTTPService(t *testing.T) {
+	cfg, err := LoadConfig("./testdata/setters-httpservice.toml")
+	require.NoError(t, err)
+
+	cfg.SetInternalPort(1234)
+	cfg.SetHttpCheck("/status")
+	cfg.SetConcurrency(12, 34)
+
+	assert.Empty(t, cfg.Services)
+	assert.Equal(t, cfg.HTTPService, &HTTPService{
+		InternalPort: 1234,
+		Concurrency: &api.MachineServiceConcurrency{
+			Type:      "connections",
+			HardLimit: 34,
+			SoftLimit: 12,
+		},
+	})
+	assert.Equal(t, cfg.Checks, map[string]*ToplevelCheck{
+		"status": {
+			Port:              api.Pointer(1234),
+			Type:              api.Pointer("http"),
+			Interval:          api.MustParseDuration("10s"),
+			Timeout:           api.MustParseDuration("2s"),
+			GracePeriod:       api.MustParseDuration("5s"),
+			HTTPMethod:        api.Pointer("GET"),
+			HTTPPath:          api.Pointer("/status"),
+			HTTPProtocol:      api.Pointer("http"),
+			HTTPTLSSkipVerify: api.Pointer(false),
+		},
+	})
+	// No need to test RawDefinition because http_service is machines only
+}
+
 func TestSettersWithouServices(t *testing.T) {
 	cfg := NewConfig()
 	cfg.SetInternalPort(1234)
 	cfg.SetHttpCheck("/status")
 	cfg.SetConcurrency(12, 34)
 	assert.Nil(t, cfg.Services, nil)
-	assert.Nil(t, cfg.HttpService, nil)
+	assert.Nil(t, cfg.HTTPService, nil)
 	assert.Equal(t, cfg.RawDefinition, map[string]any{})
 }
 
@@ -206,10 +239,10 @@ func TestSetStatics(t *testing.T) {
 
 func TestSetVolumes(t *testing.T) {
 	cfg := NewConfig()
-	cfg.SetVolumes([]Volume{{Source: "data", Destination: "/data"}})
-	assert.Equal(t, cfg.Mounts, &Volume{Source: "data", Destination: "/data"})
+	cfg.SetMounts([]Mount{{Source: "data", Destination: "/data"}})
+	assert.Equal(t, cfg.Mounts, []Mount{{Source: "data", Destination: "/data"}})
 	assert.Equal(t, cfg.RawDefinition, map[string]any{
-		"mounts": []Volume{
+		"mounts": []Mount{
 			{Source: "data", Destination: "/data"},
 		},
 	})
@@ -218,6 +251,6 @@ func TestSetVolumes(t *testing.T) {
 func TestSetKillSignal(t *testing.T) {
 	cfg := NewConfig()
 	cfg.SetKillSignal("TERM")
-	assert.Equal(t, cfg.KillSignal, "TERM")
+	assert.Equal(t, cfg.KillSignal, api.Pointer("TERM"))
 	assert.Equal(t, cfg.RawDefinition, map[string]any{"kill_signal": "TERM"})
 }
