@@ -25,6 +25,7 @@ import (
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/env"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/instrument"
 	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/metrics"
 	"github.com/superfly/flyctl/internal/state"
@@ -288,6 +289,7 @@ func initClient(ctx context.Context) (context.Context, error) {
 	// TODO: refactor so that api package does NOT depend on global state
 	api.SetBaseURL(cfg.APIBaseURL)
 	api.SetErrorLog(cfg.LogGQLErrors)
+	api.SetInstrumenter(instrument.ApiAdapter)
 	c := client.FromToken(cfg.AccessToken)
 	logger.Debug("client initialized.")
 
