@@ -157,10 +157,8 @@ func runImport(ctx context.Context) error {
 	machineConfig.Image = imageRef
 
 	launchInput := api.LaunchMachineInput{
-		AppID:   app.ID,
-		OrgSlug: app.Organization.ID,
-		Region:  region.Code,
-		Config:  machineConfig,
+		Region: region.Code,
+		Config: machineConfig,
 	}
 
 	// Create emphemeral machine
@@ -204,7 +202,7 @@ func runImport(ctx context.Context) error {
 
 	// Destroy machine
 	fmt.Fprintf(io.Out, "%s has been destroyed\n", machine.ID)
-	if err := flapsClient.Destroy(ctx, api.RemoveMachineInput{ID: machine.ID, AppID: app.ID}, machine.LeaseNonce); err != nil {
+	if err := flapsClient.Destroy(ctx, api.RemoveMachineInput{ID: machine.ID}, machine.LeaseNonce); err != nil {
 		return fmt.Errorf("failed to destroy machine %s: %s", machine.ID, err)
 	}
 
